from .module_imports import key
from uplink.retry.when import status_5xx
from uplink import (
    Consumer,
    get as http_get,
    post,
    patch,
    delete,
    returns,
    headers,
    retry,
    Body,
    json,
    Query,
)


@headers({"Ocp-Apim-Subscription-Key": key})
@retry(max_attempts=20, when=status_5xx())
class Technical_Content_Feedback(Consumer):
    """Inteface to Technical Content Feedback resource for the RockyRoad API."""

    def __init__(self, Resource, *args, **kw):
        self._base_url = Resource._base_url
        super().__init__(base_url=Resource._base_url, *args, **kw)

    def entries(self):
        return self.__Entries(self)

    def productLines(self):
        return self.__Product_lines(self)

    def technicalAreas(self):
        return self.__Technical_Areas(self)

    def administrators(self):
        return self.__Administrators(self)

    def assignments(self):
        return self.__Assignments(self)

    @headers({"Ocp-Apim-Subscription-Key": key})
    @retry(max_attempts=20, when=status_5xx())
    class __Entries(Consumer):
        """Inteface to Technical Content Feedback Entries resource for the RockyRoad API."""

        def __init__(self, Resource, *args, **kw):
            self._base_url = Resource._base_url
            super().__init__(base_url=Resource._base_url, *args, **kw)

        def logs(self):
            return self.__Logs(self)

        @returns.json
        @http_get("technical-content-feedback/entries")
        def list(
            self,
            uid: Query = None,
        ):
            """This call will return detailed technical content feedback information for the specified criteria."""

        @returns.json
        @http_get("technical-content-feedback/entries/{uid}")
        def get(
            self,
            uid: str,
        ):
            """This call will return detailed technical content feedback information for the specified criteria."""

        @delete("technical-content-feedback/entries/{uid}")
        def delete(self, uid: str):
            """This call will delete the technical content feedback for the specified uid."""

        @returns.json
        @json
        @post("technical-content-feedback/entries")
        def insert(self, entry: Body):
            """This call will create a technical content feedback with the specified parameters."""

        @json
        @patch("technical-content-feedback/entries/{uid}")
        def update(self, uid: str, entry: Body):
            """This call will update the technical content feedback with the specified parameters."""

        @headers({"Ocp-Apim-Subscription-Key": key})
        @retry(max_attempts=20, when=status_5xx())
        class __Logs(Consumer):
            """Inteface to Technical Content Feedback Logs resource for the RockyRoad API."""

            def __init__(self, Resource, *args, **kw):
                super().__init__(base_url=Resource._base_url, *args, **kw)

            @returns.json
            @http_get("technical-content-feedback/entries/{entry_uid}/logs")
            def list(
                self,
                entry_uid: str,
            ):
                """This call will return log information for the specified entry uid."""

            @returns.json
            @http_get("technical-content-feedback/entries/logs/{log_uid}")
            def get(self, log_uid: str):
                """This call will return log information for the specified log uid."""

            @returns.json
            @delete("technical-content-feedback/entries/logs/{log_uid}")
            def delete(self, log_uid: str):
                """This call will delete the log information for the specified log uid."""

            @returns.json
            @json
            @post("technical-content-feedback/entries/{entry_uid}/logs")
            def insert(self, entry_uid: str, log: Body):
                """This call will create log information with the specified parameters."""

            @returns.json
            @json
            @patch("technical-content-feedback/entries/logs/{log_uid}")
            def update(self, log_uid: str, log: Body):
                """This call will update the log information with the specified parameters."""


    @headers({"Ocp-Apim-Subscription-Key": key})
    @retry(max_attempts=20, when=status_5xx())
    class __Product_lines(Consumer):
        """Inteface to Technical Content Feedback Product Lines resource for the RockyRoad API."""

        def __init__(self, Resource, *args, **kw):
            self._base_url = Resource._base_url
            super().__init__(base_url=Resource._base_url, *args, **kw)

        @returns.json
        @http_get("technical-content-feedback/product-lines")
        def list(self):
            """This call will return a list of product lines."""
        
        @returns.json
        @http_get("technical-content-feedback/product-lines/{uid}")
        def get(self, uid: str):
            """This call will return a product line for the specified uid."""
        
        @returns.json
        @json
        @post("technical-content-feedback/product-lines")
        def insert(self, product_line: Body):
            """This call will create a product line with the specified parameters."""
        
        @json
        @patch("technical-content-feedback/product-lines/{uid}")
        def update(self, uid: str, product_line: Body):
            """This call will update the product line with the specified parameters."""
        
        @delete("technical-content-feedback/product-lines/{uid}")
        def delete(self, uid: str):
            """This call will delete the product line for the specified uid."""
        
    
    @headers({"Ocp-Apim-Subscription-Key": key})
    @retry(max_attempts=20, when=status_5xx())
    class __Technical_Areas(Consumer):
        """Inteface to Technical Content Feedback Technical Areas resource for the RockyRoad API."""

        def __init__(self, Resource, *args, **kw):
            self._base_url = Resource._base_url
            super().__init__(base_url=Resource._base_url, *args, **kw)

        @returns.json
        @http_get("technical-content-feedback/technical-areas")
        def list(self):
            """This call will return a list of technical areas."""
        
        @returns.json
        @http_get("technical-content-feedback/technical-areas/{uid}")
        def get(self, uid: str):
            """This call will return a technical area for the specified uid."""
        
        @returns.json
        @json
        @post("technical-content-feedback/technical-areas")
        def insert(self, technical_area: Body):
            """This call will create a technical area with the specified parameters."""
        
        @json
        @patch("technical-content-feedback/technical-areas/{uid}")
        def update(self, uid: str, technical_area: Body):
            """This call will update the technical area with the specified parameters."""
        
        @delete("technical-content-feedback/technical-areas/{uid}")
        def delete(self, uid: str):
            """This call will delete the technical area for the specified uid."""

    @headers({"Ocp-Apim-Subscription-Key": key})
    @retry(max_attempts=20, when=status_5xx())
    class __Administrators(Consumer):
        """Inteface to Technical Content Feedback Administrators resource for the RockyRoad API."""

        def __init__(self, Resource, *args, **kw):
            self._base_url = Resource._base_url
            super().__init__(base_url=Resource._base_url, *args, **kw)

        @returns.json
        @http_get("technical-content-feedback/administrators")
        def list(self):
            """This call will return a list of administrators."""
        
        @returns.json
        @http_get("technical-content-feedback/administrators/{uid}")
        def get(self, uid: str):
            """This call will return an administrator for the specified uid."""
        
        @returns.json
        @json
        @post("technical-content-feedback/administrators")
        def insert(self, administrator: Body):
            """This call will create an  administrator with the specified parameters."""
        
        @json
        @patch("technical-content-feedback/administrators/{uid}")
        def update(self, uid: str, administrator: Body):
            """This call will update the administrator with the specified parameters."""
        
        @delete("technical-content-feedback/administrators/{uid}")
        def delete(self, uid: str):
            """This call will delete the administrator for the specified uid."""

    @headers({"Ocp-Apim-Subscription-Key": key})
    @retry(max_attempts=20, when=status_5xx())
    class __Assignments(Consumer):
        """Inteface to Technical Content Feedback Assignments resource for the RockyRoad API."""

        def __init__(self, Resource, *args, **kw):
            self._base_url = Resource._base_url
            super().__init__(base_url=Resource._base_url, *args, **kw)

        @returns.json
        @http_get("technical-content-feedback/assignments")
        def list(self):
            """This call will return a list of assignments."""
        
        @returns.json
        @http_get("technical-content-feedback/assignments/{uid}")
        def get(self, uid: str):
            """This call will return an assignment for the specified uid."""
        
        @returns.json
        @json
        @post("technical-content-feedback/assignments")
        def insert(self, assignment: Body):
            """This call will create an assignment with the specified parameters."""
        
        @json
        @patch("technical-content-feedback/assignments/{uid}")
        def update(self, uid: str, assignment: Body):
            """This call will update the assignment with the specified parameters."""
        
        @delete("technical-content-feedback/assignments/{uid}")
        def delete(self, uid: str):
            """This call will delete the assignment for the specified uid."""
    